@@ -416,16 +416,18 @@ class SoftwareProperties(object):
                              source.dist,
                              source.comps,
                              "Added by software-properties",
-                             self.sourceslist.list.index(source)+1,
-                             source.file)
+                             self.sourceslist.index(source)+1,
+                             source.file,
+                             parent=source)
     for source in self.distro.cdrom_sources:
         self.sourceslist.add("deb-src",
                              self.distro.source_template.base_uri,
                              self.distro.source_template.name,
                              source.comps,
                              "Added by software-properties",
-                             self.sourceslist.list.index(source)+1,
-                             source.file)
+                             self.sourceslist.index(source)+1,
+                             source.file,
+                             parent=source)
     self.set_modified_sourceslist()
 
   def backup_sourceslist(self):
